@@ -7,7 +7,7 @@ OSDefineMetaClassAndStructors(AppleUSBAudioLevelControl, IOAudioLevelControl)
 AppleUSBAudioLevelControl *AppleUSBAudioLevelControl::create (UInt8 theUnitID, UInt8 theInterfaceNumber, UInt8 theControlSelector, UInt8 theChannelNumber, Boolean shouldUpdatePRAM, USBDeviceRequest theUSBDeviceRequest, void *theCallerRefCon, UInt32 subType, UInt32 usage) {
     AppleUSBAudioLevelControl *			control;
 
-    debugIOLog ("+AppleUSBAudioLevelControl::create (%d, %d, %d, %d, %p, %lX, %lX)", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
+    debugIOLog ("+ AppleUSBAudioLevelControl::create (%d, %d, %d, %d, %p, %lX, %lX)", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
     control = new AppleUSBAudioLevelControl;
     FailIf (NULL == control, Exit);
 
@@ -17,7 +17,7 @@ AppleUSBAudioLevelControl *AppleUSBAudioLevelControl::create (UInt8 theUnitID, U
     }
 
 Exit:
-    debugIOLog ("-AppleUSBAudioLevelControl::create(%d, %d, %d, %d, %p, %lX, %lX)", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
+    debugIOLog ("- AppleUSBAudioLevelControl[%p]::create (%d, %d, %d, %d, %p, %lX, %lX)", control, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
     return control;
 }
 
@@ -33,36 +33,39 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 	Boolean						result;
 	Boolean						arePRAMControl;
 
-	debugIOLog ("+AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
+	debugIOLog ("+ AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
 	result = FALSE;
 	arePRAMControl = FALSE;
 
 	FailIf (NULL == theUSBDeviceRequest, Exit);
-	setValueThreadCall = thread_call_allocate ((thread_call_func_t)updateValueCallback, this);
-	FailIf (NULL == setValueThreadCall, Exit);
+	mSetValueThreadCall = thread_call_allocate ((thread_call_func_t)updateValueCallback, this);
+	FailIf (NULL == mSetValueThreadCall, Exit);
 
 	// If this control is supposed to be a pram volume control, pretend we're just a regular volume control
 	// so that we can get the min and max dB from the device as we init
-	if (theControlSelector == 0xff) {
+	if (theControlSelector == 0xff) 
+	{
 		theControlSelector = VOLUME_CONTROL;
 		arePRAMControl = TRUE;
 	}
 
-	if (kIOAudioLevelControlSubTypeLFEVolume == subType) {
+	if (kIOAudioLevelControlSubTypeLFEVolume == subType) 
+	{
 		// The iSub controls are on channels 1 and 2, but we want to make them look like they're on channel 0 for the HAL
 		// set it to 1 here so we can query the iSub
 		theChannelNumber = 1;
 	}
 
-	unitID = theUnitID;
-	interfaceNumber = theInterfaceNumber;
-	controlSelector = theControlSelector;
-	channelNumber = theChannelNumber;
-	callerRefCon = theCallerRefCon;
-	usbDeviceRequest = theUSBDeviceRequest;
+	mUnitID = theUnitID;
+	mInterfaceNumber = theInterfaceNumber;
+	mControlSelector = theControlSelector;
+	mChannelNumber = theChannelNumber;
+	mCallerRefCon = theCallerRefCon;
+	mUSBDeviceRequest = theUSBDeviceRequest;
 	fShouldUpdatePRAM = shouldUpdatePRAM;
 
-	switch (channelNumber) {
+	switch (mChannelNumber) 
+	{
 		case kIOAudioControlChannelIDAll:
 			channelName = kIOAudioControlChannelNameAll;
 			break;
@@ -73,64 +76,69 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 			channelName = kIOAudioControlChannelNameRight;
 			break;
 		case 0xff:
-			debugIOLog ("++AppleUSBAudioLevelControl: Does not support channel number 0xff.");
+			debugIOLog ("! AppleUSBAudioLevelControl[%p]::init () - Does not support channel number 0xFF.", this);
 			return FALSE;
 		default:
 			channelName = "Unknown";
 			break;
 	}
 
-	ret = GetCurVolume (interfaceNumber, channelNumber, &currentValue);
+	ret = GetCurVolume (mInterfaceNumber, mChannelNumber, &currentValue);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debugIOLog ("channelNumber %d, currentValue = 0x%X, ", channelNumber, currentValue);
-	ret = GetVolumeResolution (interfaceNumber, channelNumber, &volRes);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - mChannelNumber %d, currentValue = 0x%X", this, mChannelNumber, currentValue);
+	ret = GetVolumeResolution (mInterfaceNumber, mChannelNumber, &mVolRes);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debugIOLog ("vol res = %d, ", volRes);
-	ret = GetMinVolume (interfaceNumber, channelNumber, &deviceMin);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - mVolRes = %d, ", this, mVolRes);
+	ret = GetMinVolume (mInterfaceNumber, mChannelNumber, &deviceMin);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debugIOLog ("deviceMin = 0x%X, ", deviceMin);
-	ret = GetMaxVolume (interfaceNumber, channelNumber, &deviceMax);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - deviceMin = 0x%X, ", this, deviceMin);
+	ret = GetMaxVolume (mInterfaceNumber, mChannelNumber, &deviceMax);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debugIOLog ("deviceMax = 0x%X", deviceMax);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - deviceMax = 0x%X", this, deviceMax);
 
 	// Having the device say that it does -infinity dB messes up our math, so set the min at -127.9961dB instead.
-	if ((SInt16)0x8000 == deviceMin) {
+	if ((SInt16)0x8000 == deviceMin) 
+	{
 		deviceMin = (SInt16)0x8001;
-		debugIOLog ("deviceMin adjusted to = %d", deviceMin);
+		debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - deviceMin adjusted to = %d", this, deviceMin);
 	}
 
 	deviceMinDB = ConvertUSBVolumeTodB (deviceMin);
 	deviceMaxDB = ConvertUSBVolumeTodB (deviceMax);
-	resolutionDB = ConvertUSBVolumeTodB (volRes);		// The volume is incremented in units of this many dB, represented as 1/256 dB (eg 256 == 1dB of control)
+	resolutionDB = ConvertUSBVolumeTodB (mVolRes);		// The volume is incremented in units of this many dB, represented as 1/256 dB (eg 256 == 1dB of control)
 
-	offset = -deviceMin;
-	debugIOLog ("offset = %d", offset);
+	mOffset = -deviceMin;
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - mOffset = %d", this, mOffset);
 
-	currentValue = (currentValue + offset) / volRes;
-	if (deviceMin < 0 && deviceMax > 0) {
-		deviceMax += volRes;
-		debugIOLog ("deviceMax adjusted to = 0x%X", deviceMax);
+	currentValue = (currentValue + mOffset) / mVolRes;
+	if (deviceMin < 0 && deviceMax > 0) 
+	{
+		deviceMax += mVolRes;
+		debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - deviceMax adjusted to = 0x%X", this, deviceMax);
 	}
-	deviceMax = ((deviceMin + offset) + (deviceMax + offset)) / volRes;
+	deviceMax = ((deviceMin + mOffset) + (deviceMax + mOffset)) / mVolRes;
 
-	if (kIOAudioLevelControlSubTypeLFEVolume == subType) {
+	if (kIOAudioLevelControlSubTypeLFEVolume == subType) 
+	{
 		currentValue = currentValue / 2;
 		//updateUSBValue (currentValue);
 	}
 
 	// Set values needed to compute proper PRAM boot beep volume setting
 	fMaxVolume = deviceMax;
-	fMinVolume = deviceMin + offset;
+	fMinVolume = deviceMin + mOffset;
 	deviceMin = -1;
 
-	if (arePRAMControl) {
+	if (arePRAMControl) 
+	{
 		// If this is a 'pram' control then there is no need to call the hardware.
 		UInt8 						curPRAMVol;
 		IODTPlatformExpert * 		platform = NULL;
 
 		curPRAMVol = 0;
 		platform = OSDynamicCast (IODTPlatformExpert, getPlatform ());
-		if (NULL != platform) {
+		if (NULL != platform) 
+		{
 			platform->readXPRAM ((IOByteCount)kPRamVolumeAddr, &curPRAMVol, (IOByteCount)1);
 			curPRAMVol = (curPRAMVol & 0xF8);
 		}
@@ -142,56 +150,59 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 		theChannelNumber = 0;	// force it to the master channel even though we're piggy backing off of the channel 1 control
 	}
 
-	if (kIOAudioLevelControlSubTypeLFEVolume == subType) {
+	if (kIOAudioLevelControlSubTypeLFEVolume == subType) 
+	{
 		// The iSub controls are on channels 1 and 2, but we want to make them look like they're on channel 0 for the HAL
 		theChannelNumber = 0;
 		channelName = kIOAudioControlChannelNameAll;
 	}
 
-//	debugIOLog ("min = %d, max = %d, current = %d", (deviceMin + offset) - 1, deviceMax, currentValue);
-	debugIOLog ("min = %d, max = %d, current = %d", deviceMin, deviceMax, currentValue);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::init () - min = %d, max = %d, current = %d", this, deviceMin, deviceMax, currentValue);
 
 	FailIf (FALSE == super::init (currentValue, deviceMin, deviceMax, deviceMinDB, deviceMaxDB, theChannelNumber, channelName, 0, subType, usage), Exit);
 
-	if (kIOAudioLevelControlSubTypeLFEVolume == subType) {
+	if (kIOAudioLevelControlSubTypeLFEVolume == subType) 
+	{
 		updateUSBValue (currentValue);
 	}
 
 	result = TRUE;
 
 Exit:
-	debugIOLog ("-AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
+	debugIOLog ("- AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
 	return result;
 }
 
 void AppleUSBAudioLevelControl::free () {
-    debugIOLog ("+AppleUSBAudioLevelControl[%p]::free ()", this);
+    debugIOLog ("+ AppleUSBAudioLevelControl[%p]::free ()", this);
 
-    if (setValueThreadCall) {
-        thread_call_free (setValueThreadCall);
-        setValueThreadCall = NULL;
+    if (mSetValueThreadCall) 
+	{
+        thread_call_free (mSetValueThreadCall);
+        mSetValueThreadCall = NULL;
     }
 
     super::free ();
-    debugIOLog ("-AppleUSBAudioLevelControl[%p]::free ()", this);
+    debugIOLog ("- AppleUSBAudioLevelControl[%p]::free ()", this);
 }
 
 IOReturn AppleUSBAudioLevelControl::performValueChange (OSObject * newValue) {
 	OSNumber *					newValueAsNumber;
 	SInt32						newValueAsSInt32;
 
-    debugIOLog ("+AppleUSBAudioLevelControl[%p]::performValueChange (%d)", this, newValue); 
+    debugIOLog ("+ AppleUSBAudioLevelControl[%p]::performValueChange (%p)", this, newValue); 
 
 	newValueAsNumber = OSDynamicCast (OSNumber, newValue);
 	FailIf (NULL == newValueAsNumber, Exit);
 	newValueAsSInt32 = newValueAsNumber->unsigned32BitValue ();
-	debugIOLog ("++AppleUSBAudioLevelControl[%p]::performValueChange (%ld)", this, newValueAsSInt32);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::performValueChange (%ld) [converted]", this, newValueAsSInt32);
 
-    if (NULL != setValueThreadCall) {
-        thread_call_enter1 (setValueThreadCall, (thread_call_param_t)newValueAsSInt32);
+    if (NULL != mSetValueThreadCall) 
+	{
+        thread_call_enter1 (mSetValueThreadCall, (thread_call_param_t)newValueAsSInt32);
     }
 
-    debugIOLog ("-AppleUSBAudioLevelControl[%p]::performValueChange (%d)", this, newValueAsSInt32);
+    debugIOLog ("- AppleUSBAudioLevelControl[%p]::performValueChange (%d)", this, newValueAsSInt32);
 
 Exit:
     return kIOReturnSuccess;
@@ -207,65 +218,45 @@ void AppleUSBAudioLevelControl::updateUSBValue (SInt32 newValue) {
 	SInt16						newVolume;
     IOReturn					ret;
 
-    debugIOLog ("+AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)", this, newValue);
+    debugIOLog ("+ AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)", this, newValue);
 
-	if (newValue < 0) {
+	if (newValue < 0) 
+	{
 		newVolume = 0x8000;
-	} else {
-		if (newValue > 0) {
-			newVolume = ((newValue - 1) * volRes) - offset;
-		} else {
-			newVolume = (newValue * volRes) - offset;
+	} 
+	else 
+	{
+		if (newValue > 0) 
+		{
+			newVolume = ((newValue - 1) * mVolRes) - mOffset;
+		} 
+		else 
+		{
+			newVolume = (newValue * mVolRes) - mOffset;
 		}
 	}
-	debugIOLog ("volume value is 0x%X", newVolume);
     theValue = HostToUSBWord (newVolume);
-	debugIOLog ("setting volume to 0x%X (little endian)", newVolume);
-	ret = SetCurVolume (interfaceNumber, channelNumber, theValue);
+	debugIOLog ("? AppleUSBAudioLevelControl[%p]::updateUSBValue () - Volume value is 0x%x. Setting volume to 0x%x (little endian)", this, newVolume, theValue);
+	ret = SetCurVolume (mInterfaceNumber, mChannelNumber, theValue);
 
-	if (getSubType () == kIOAudioLevelControlSubTypeLFEVolume) {
+	if (getSubType () == kIOAudioLevelControlSubTypeLFEVolume) 
+	{
 		// We set the iSub's left volume (on channel 1 above), now set it on channel 2 to mimic having only a master volume control
-		ret = SetCurVolume (interfaceNumber, 2, theValue);
+		ret = SetCurVolume (mInterfaceNumber, 2, theValue);
 	}
 
-	if (TRUE == fShouldUpdatePRAM && FALSE == gExpertMode) {				// We do that only if we are on a OS 9 like UI guideline
+	if (TRUE == fShouldUpdatePRAM && FALSE == gExpertMode) 
+	{	
+		// We do that only if we are on a OS 9 like UI guideline
 		WritePRAMVol (newValue, newValue);
 	}
-#if 0
-	// If this is the iSub volume control, don't bother to look for ourselves, which would probably result in an infinite loop anyway.
-	if (getSubType () != kIOAudioLevelControlSubTypeLFEVolume && getUsage () == kIOAudioControlUsageOutput) {
-		IOAudioLevelControl *	iSubVolume;
-		IORegistryEntry *		start;
-		IORegistryEntry *		parent;
-		IORegistryEntry *		engine;
-
-		iSubVolume = NULL;
-		debugIOLog ("Looking for iSub volume control");
-		start = getParentEntry (gIOServicePlane);
-		FailIf (NULL == start, Exit);
-		parent = start->getParentEntry (gIOServicePlane);
-		FailIf (NULL == parent, Exit);
-		engine = parent->childFromPath ("AppleUSBAudioEngine", gIOServicePlane);
-		FailIf (NULL == engine, Exit);
-
-		iSubVolume = (IOAudioLevelControl *)FindEntryByNameAndProperty (engine, "AppleUSBAudioLevelControl", kIOAudioControlSubTypeKey, kIOAudioLevelControlSubTypeLFEVolume);
-
-		engine->release ();
-
-		if (NULL != iSubVolume) {
-			newiSubVolume = ((newValue * kiSubMaxVolume) / getMaxValue ()) * kiSubVolumePercent / 100;
-			debugIOLog ("Setting the iSub volume control");
-			iSubVolume->setValue (newiSubVolume);
-			iSubVolume->release ();
-		}
-	}
-#endif
-//Exit:
-    if (ret != kIOReturnSuccess) {
-        debugIOLog ("++AppleUSBAudioLevelContol:updateUSBValue () - set current value for %d:%d failed: 0x%X", controlSelector, channelNumber, ret);
+	
+    if (ret != kIOReturnSuccess) 
+	{
+        debugIOLog ("! AppleUSBAudioLevelContol::updateUSBValue () - Set current value for control selector %d, channel number %d failed with error 0x%X", mControlSelector, mChannelNumber, ret);
     }
 
-    debugIOLog ("-AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)", this, newValue);
+    debugIOLog ("- AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)", this, newValue);
 }
 
 IOReturn AppleUSBAudioLevelControl::GetCurVolume (UInt8 interfaceNumber, UInt8 channelNumber, SInt16 * target) {
@@ -279,18 +270,19 @@ IOReturn AppleUSBAudioLevelControl::GetCurVolume (UInt8 interfaceNumber, UInt8 c
 	
     devReq.bmRequestType = USBmakebmRequestType (kUSBIn, kUSBClass, kUSBInterface);
     devReq.bRequest = GET_CUR;
-    devReq.wValue = (controlSelector << 8) | channelNumber;
-    devReq.wIndex = (unitID << 8) | interfaceNumber;
+    devReq.wValue = (mControlSelector << 8) | channelNumber;
+    devReq.wIndex = (mUnitID << 8) | interfaceNumber;
     devReq.wLength = 2;
     devReq.pData = &theVolume;
 
-	result = usbDeviceRequest (&devReq, callerRefCon);
+	result = mUSBDeviceRequest (&devReq, mCallerRefCon, NULL);
     FailIf (kIOReturnSuccess != result, Exit);
 
 Exit:
-	if (NULL != target) {
+	if (NULL != target) 
+	{
 		* target = USBToHostWord (theVolume);
-		}
+	}
     return result;
 }
 
@@ -305,16 +297,17 @@ IOReturn AppleUSBAudioLevelControl::GetMaxVolume (UInt8 interfaceNumber, UInt8 c
 	
     devReq.bmRequestType = USBmakebmRequestType (kUSBIn, kUSBClass, kUSBInterface);
     devReq.bRequest = GET_MAX;
-    devReq.wValue = (controlSelector << 8) | channelNumber;
-    devReq.wIndex = (unitID << 8) | interfaceNumber;
+    devReq.wValue = (mControlSelector << 8) | channelNumber;
+    devReq.wIndex = (mUnitID << 8) | interfaceNumber;
     devReq.wLength = 2;
     devReq.pData = &theVolume;
 
-	result = usbDeviceRequest (&devReq, callerRefCon);
+	result = mUSBDeviceRequest (&devReq, mCallerRefCon, NULL);
     FailIf (kIOReturnSuccess != result, Exit);
 
 Exit:
-	if (NULL != target) {
+	if (NULL != target) 
+	{
 		* target = USBToHostWord (theVolume);
 	}
     return result;
@@ -331,16 +324,17 @@ IOReturn AppleUSBAudioLevelControl::GetMinVolume (UInt8 interfaceNumber, UInt8 c
 	
 	devReq.bmRequestType = USBmakebmRequestType (kUSBIn, kUSBClass, kUSBInterface);
     devReq.bRequest = GET_MIN;
-    devReq.wValue = (controlSelector << 8) | channelNumber;
-    devReq.wIndex = (unitID << 8) | interfaceNumber;
+    devReq.wValue = (mControlSelector << 8) | channelNumber;
+    devReq.wIndex = (mUnitID << 8) | interfaceNumber;
     devReq.wLength = 2;
     devReq.pData = &theVolume;
 
-	result = usbDeviceRequest (&devReq, callerRefCon);
+	result = mUSBDeviceRequest (&devReq, mCallerRefCon, NULL);
     FailIf (kIOReturnSuccess != result, Exit);
 
 Exit:
-	if (NULL != target) {
+	if (NULL != target) 
+	{
 		* target = USBToHostWord (theVolume);
 	}
     return result;
@@ -357,16 +351,17 @@ IOReturn AppleUSBAudioLevelControl::GetVolumeResolution (UInt8 interfaceNumber,
 	
     devReq.bmRequestType = USBmakebmRequestType (kUSBIn, kUSBClass, kUSBInterface);
     devReq.bRequest = GET_RES;
-    devReq.wValue = (controlSelector << 8) | channelNumber;
-    devReq.wIndex = (unitID << 8) | interfaceNumber;
+    devReq.wValue = (mControlSelector << 8) | channelNumber;
+    devReq.wIndex = (mUnitID << 8) | interfaceNumber;
     devReq.wLength = 2;
     devReq.pData = &theResolution;
 
-	result = usbDeviceRequest (&devReq, callerRefCon);
+	result = mUSBDeviceRequest (&devReq, mCallerRefCon, NULL);
     FailIf (kIOReturnSuccess != result, Exit);
 
 Exit:
-	if (NULL != target) {
+	if (NULL != target) 
+	{
 		* target = USBToHostWord (theResolution);
 	}
     return result;
@@ -378,20 +373,20 @@ IOReturn AppleUSBAudioLevelControl::SetCurVolume (UInt8 interfaceNumber, UInt8 c
 
     devReq.bmRequestType = USBmakebmRequestType (kUSBOut, kUSBClass, kUSBInterface);
     devReq.bRequest = SET_CUR;
-    devReq.wValue = (controlSelector << 8) | channelNumber;
-    devReq.wIndex = (unitID << 8) | interfaceNumber;
+    devReq.wValue = (mControlSelector << 8) | channelNumber;
+    devReq.wIndex = (mUnitID << 8) | interfaceNumber;
     devReq.wLength = 2;
     devReq.pData = &volume;
 
 	FailIf ((TRUE == isInactive()), DeviceInactive);  	// In case we've been unplugged during sleep
-	error = usbDeviceRequest (&devReq, callerRefCon);
+	error = mUSBDeviceRequest (&devReq, mCallerRefCon, NULL);
     FailIf (kIOReturnSuccess != error, Exit);
 
 Exit:
     return error;
 	
 DeviceInactive:
-	debugIOLog("AppleUSBAudioLevelControl::SetCurVolume ERROR attempt to send a device request to and inactive device");
+	debugIOLog("! AppleUSBAudioLevelControl::SetCurVolume () - ERROR attempt to send a device request to and inactive device");
 	error = kIOReturnError;
 	goto Exit;
 }
@@ -401,29 +396,34 @@ void AppleUSBAudioLevelControl::updateValueCallback (void *arg1, void *arg2) {
     SInt32							value;
 	UInt32							subType;
 
-    debugIOLog ("+AppleUSBAudioLevelControl::updateValueCallback (%p, %p)", (UInt32*)arg1, (UInt32*)arg2);
+    debugIOLog ("+ AppleUSBAudioLevelControl::updateValueCallback (%p, %p)", (UInt32*)arg1, (UInt32*)arg2);
     levelControl = OSDynamicCast (AppleUSBAudioLevelControl, (OSObject*)arg1);
     value = (SInt32)arg2;
 
-    if (levelControl) {
+    if (levelControl) 
+	{
 		subType = levelControl->getSubType ();
 		
-		if (kIOAudioLevelControlSubTypePRAMVolume == subType) {
+		if (kIOAudioLevelControlSubTypePRAMVolume == subType) 
+		{
 			UInt8 						curPRAMVol;
 			IODTPlatformExpert * 		platform = NULL;
 
 			platform = OSDynamicCast (IODTPlatformExpert, getPlatform ());
-			if (NULL != platform) {
+			if (NULL != platform) 
+			{
 				platform->readXPRAM ((IOByteCount)kPRamVolumeAddr, &curPRAMVol, (IOByteCount)1);
 				curPRAMVol = (curPRAMVol & 0xF8) | value;
 				platform->writeXPRAM ((IOByteCount)kPRamVolumeAddr, &curPRAMVol, (IOByteCount)1);
 			}
-		} else {
+		} 
+		else 
+		{
 			levelControl->updateUSBValue (value);
 		}
     }
 
-    debugIOLog ("-AppleUSBAudioLevelControl::updateValueCallback (%p, %p)", (UInt32*)arg1, (UInt32*)arg2);
+    debugIOLog ("- AppleUSBAudioLevelControl::updateValueCallback (%p, %p)", (UInt32*)arg1, (UInt32*)arg2);
 }
 
 // This is how the thing is defined in the USB Audio spec (section 5.2.2.4.3.2 for the curious).
@@ -433,47 +433,20 @@ void AppleUSBAudioLevelControl::updateValueCallback (void *arg1, void *arg2) {
 IOFixed AppleUSBAudioLevelControl::ConvertUSBVolumeTodB (SInt16 volume) {
 	IOFixed							dBVolumeFixed;
 
-	if (volume == (SInt16)0x8000) {
+	if (volume == (SInt16)0x8000) 
+	{
 		dBVolumeFixed = ((SInt16)0x8000 * 256) << 8;	// really is negative infinity
-	} else {
+	} 
+	else 
+	{
 		dBVolumeFixed = volume * 256;
 	}
 
-	debugIOLog ("volume = %d, dBVolumeFixed = 0x%X", volume, dBVolumeFixed);
+	debugIOLog ("? AppleUSBAudioLevelControl::ConvertUSBVolumeTodB () - volume = %d, dBVolumeFixed = 0x%X", volume, dBVolumeFixed);
 
 	return dBVolumeFixed;
 }
-#if 0
-IORegistryEntry * AppleUSBAudioLevelControl::FindEntryByNameAndProperty (const IORegistryEntry * start, const char * name, const char * key, UInt32 value) {
-	OSIterator				*iterator;
-	IORegistryEntry			*theEntry;
-	IORegistryEntry			*tmpReg;
-	OSNumber				*tmpNumber;
 
-	theEntry = NULL;
-	iterator = NULL;
-	FailIf (NULL == start, Exit);
-
-	iterator = start->getChildIterator (gIOServicePlane);
-	FailIf (NULL == iterator, Exit);
-
-	while (NULL == theEntry && (tmpReg = OSDynamicCast (IORegistryEntry, iterator->getNextObject ())) != NULL) {
-		if (strcmp (tmpReg->getName (), name) == 0) {
-			tmpNumber = OSDynamicCast (OSNumber, tmpReg->getProperty (key));
-			if (NULL != tmpNumber && tmpNumber->unsigned32BitValue () == value) {
-				theEntry = tmpReg;
-				theEntry->retain ();
-			}
-		}
-	}
-
-Exit:
-	if (NULL != iterator) {
-		iterator->release ();
-	}
-	return theEntry;
-}
-#endif
 #pragma mark +PRAM VOLUME
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //	Calculates the PRAM volume value for stereo volume.
@@ -497,7 +470,8 @@ UInt8 AppleUSBAudioLevelControl::VolumeToPRAMValue (SInt32 leftVol, SInt32 right
 	// flashing the menu bar when it thinks sound is off and
 	// should really just be very quiet.
 
-	if ((pramVolume == 0) && (leftVol != 0 || rightVol !=0 )) {
+	if ((pramVolume == 0) && (leftVol != 0 || rightVol !=0 )) 
+	{
 		pramVolume = 1;
 	}
 
@@ -511,19 +485,21 @@ void AppleUSBAudioLevelControl::WritePRAMVol (SInt32 leftVol, SInt32 rightVol) {
 
 	platform = OSDynamicCast (IODTPlatformExpert, getPlatform ());
 
-    debugIOLog ("AppleUSBTrinityAudioDevice::WritePRAMVol leftVol=%lu, rightVol=%lu",leftVol,  rightVol);
+    debugIOLog ("? AppleUSBAudioLevelControl::WritePRAMVol () - leftVol = %lu, rightVol = %lu",leftVol,  rightVol);
 
-    if (NULL != platform) {
+    if (NULL != platform) 
+	{
 		pramVolume = VolumeToPRAMValue (leftVol, rightVol);
 
 		// get the old value to compare it with
 		platform->readXPRAM ((IOByteCount)kPRamVolumeAddr, &curPRAMVol, (IOByteCount)1);
 
 		// Update only if there is a change
-		if (pramVolume != (curPRAMVol & 0x07)) {
+		if (pramVolume != (curPRAMVol & 0x07)) 
+		{
 			// clear bottom 3 bits of volume control byte from PRAM low memory image
 			curPRAMVol = (curPRAMVol & 0xF8) | pramVolume;
-            debugIOLog ("AppleUSBAudioLevelControl::WritePRAMVol curPRAMVol=0x%x", curPRAMVol);
+            debugIOLog ("? AppleUSBAudioLevelControl::WritePRAMVol () - curPRAMVol = 0x%x", curPRAMVol);
 
 			// write out the volume control byte to PRAM
 			platform->writeXPRAM ((IOByteCount)kPRamVolumeAddr, &curPRAMVol, (IOByteCount) 1);
