@@ -25,7 +25,7 @@ __END_DECLS
 class AppleUSBAudioDevice;
 typedef struct call_entry *thread_call_t;
 
-typedef IOReturn (*USBDeviceRequest)(IOUSBDevRequest * request, void * refCon = 0, IOUSBCompletion * completion = 0);
+typedef IOReturn (*USBDeviceRequest)(IOUSBDevRequest * request, void * refCon, IOUSBCompletion * completion);
 
 // PRAM read write values
 enum{
@@ -45,15 +45,15 @@ class AppleUSBAudioLevelControl : public IOAudioLevelControl
 {
     OSDeclareDefaultStructors(AppleUSBAudioLevelControl);
 
-    UInt8					unitID;
-    UInt8					interfaceNumber;
-    UInt8					controlSelector;
-    UInt8					channelNumber;
-    SInt16					offset;
-	UInt16					volRes;
-    thread_call_t			setValueThreadCall;
-    USBDeviceRequest		usbDeviceRequest;
-	void *					callerRefCon;
+    UInt8					mUnitID;
+    UInt8					mInterfaceNumber;
+    UInt8					mControlSelector;
+    UInt8					mChannelNumber;
+    SInt16					mOffset;
+	UInt16					mVolRes;
+    thread_call_t			mSetValueThreadCall;
+    USBDeviceRequest		mUSBDeviceRequest;
+	void *					mCallerRefCon;
 	Boolean					gExpertMode;
     UInt32					fMaxVolume;
     UInt32					fMinVolume;
