@@ -17,9 +17,7 @@
 class AppleUSBTrinityAudioDevice : public AppleUSBAudioDevice {
     OSDeclareDefaultStructors (AppleUSBTrinityAudioDevice);
 
-    IOService *				powerProvider;
-    IOPMPowerFlags			currentPowerFlags;
-    UInt32					eqRetryCount;
+    UInt32					mEQRetryCount;
 
 public:
     virtual bool			start (IOService * provider);
