@@ -278,6 +278,10 @@ UInt8 USBAudioConfigObject::FindAltInterfaceWithSettings (UInt8 interfaceNum, UI
 				debugIOLog ("? USBAudioConfigObject[%p]::FindAltInterfaceWithSettings () - No alternate setting ID for interface %d, %d channels. Terminating loop.", this, interfaceNum, numChannels);
 				break;		// Done, so break out of while loop
 			}
+			else
+			{
+				debugIOLog ("? USBAudioConfigObject[%p]::FindAltInterfaceWithSettings () - Examining alt interface %d.", this, potentialAltInterface);				
+			}
 			if (potentialAltInterface == FindNextAltInterfaceWithSampleSize (interfaceNum, potentialAltInterface, sampleSize)) 
 			{
 				if (0 != sampleRate) 
