@@ -837,6 +837,7 @@ public:
 	UInt8							GetInterfaceProtocol (void) {return interfaceProtocol;}
     UInt8							GetInterfaceSubClass (void) {return interfaceSubClass;}
 	UInt8							GetIsocAssociatedEndpointAddress (UInt8 address);
+	UInt8							GetIsocAssociatedEndpointMaxPacketSize (UInt8 address);
 	UInt8							GetIsocAssociatedEndpointRefreshInt (UInt8 address);
 	UInt8							GetIsocEndpointAddress (UInt8 direction);
 	UInt8							GetIsocEndpointDirection (UInt8 index);
@@ -873,6 +874,7 @@ public:
     virtual bool					init (const IOUSBConfigurationDescriptor * newConfigurationDescriptor, UInt8 controlInterfaceNum);
     virtual void					free (void);
 
+	bool							AlternateSettingZeroCanStream (UInt8 interfaceNum);
 	Boolean							ChannelHasMuteControl (UInt8 interfaceNum, UInt8 altInterfaceNum, UInt8 featureUnitID, UInt8 channelNum);
 	Boolean							ChannelHasVolumeControl (UInt8 interfaceNum, UInt8 altInterfaceNum, UInt8 featureUnitID, UInt8 channelNum);
 	UInt8							FindNextAltInterfaceWithNumChannels (UInt8 interfaceNum, UInt8 startingAltInterface, UInt8 numChannelsRequested);
@@ -887,6 +889,7 @@ public:
 	UInt16							GetFormat (UInt8 interfaceNum, UInt8 altInterfaceNum);
 	UInt32							GetHighestSampleRate (UInt8 interfaceNum, UInt8 altInterfaceNum);
 	UInt8							GetIsocAssociatedEndpointAddress (UInt8 interfaceNum, UInt8 altInterfaceNum, UInt8 address);
+	UInt8							GetIsocAssociatedEndpointMaxPacketSize (UInt8 interfaceNum, UInt8 altInterfaceNum, UInt8 address);
 	UInt8							GetIsocAssociatedEndpointRefreshInt (UInt8 interfaceNum, UInt8 altInterfaceNum, UInt8 address);
 	UInt8							GetIsocEndpointAddress (UInt8 interfaceNum, UInt8 altInterfaceNum, UInt8 direction);
 	UInt8							GetIsocEndpointDirection (UInt8 interfaceNum, UInt8 altInterfaceNum);
